#!/bin/bash

#author				: hennes (jm@rapidrabbit.de) -> original build-script by Michael Verret (AxXium)
#last changed		: 01-august-2007

#package			: blobwars - episode 1
#homepage			: http://www.parallelrealities.co.uk/blobwars.php
#source location	: http://www.parallelrealities.co.uk/download.php?file=blobwars-1.07-1.tar.gz&type=zip
#dependencies		: coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,perl,sdl,sysfsutils,xorg,xterm,zlib

# ----- credentials
softname="blobwars1"
softversion="1.07"
srcurl="http://www.parallelrealities.co.uk/download.php?file=blobwars-1.07-1.tar.gz&type=zip"
arch=i486
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/doc
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
         |-----handy-ruler-----------------------------------------------|
blobwars1: blobwars - episode 1 (platform game)
blobwars1:
blobwars1: The story of blobwars is set around Bob, whose mission is to
blobwars1: infiltrate the various enemy bases around the Blobs' homeworld
blobwars1: and rescue as many MIAs as possible. But standing in his way
blobwars1: are many vicious aliens, other Blobs who have been assimilated
blobwars1: and the evil alien leader, Galdov.
blobwars1:
blobwars1:
blobwars1:
blobwars1:
EOF

# ----- extract source-archive
srcdir=blobwars-$softversion
rm -rf $srcdir
if [ -f blobwars-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c --output-document="$builddir/blobwars-$softversion.tar.gz" $srcurl
fi
tar -zxvf blobwars-$softversion.tar.gz
cd $srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- make & make install
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

sed -i 's|BINDIR = $(PREFIX)/games/|BINDIR = $(PREFIX)/bin/|' \
  ./makefile
sed -i 's|DATADIR = $(PREFIX)/share/games/blobwars/|DATADIR = $(PREFIX)/share/blobwars1/|' \
  ./makefile
sed -i 's|DOCDIR = $(PREFIX)/share/doc/$(PROG)/|DOCDIR = $(PREFIX)/doc/$(PROG)1-$(VERSION)/|' \
  ./makefile
sed -i 's|cp $(ICONS)$(PROG).png $(ICONDIR)32x32/apps/|cp $(ICONS)$(PROG).png $(ICONDIR)32x32/apps/$(PROG)1.png|' \
  ./makefile
sed -i 's|cp $(ICONS)$(PROG)-mini.png $(ICONDIR)16x16/apps/$(PROG).png|cp $(ICONS)$(PROG)-mini.png $(ICONDIR)16x16/apps/$(PROG)1.png|' \
  ./makefile
sed -i 's|cp $(ICONS)$(PROG)-large.png $(ICONDIR)64x64/apps/$(PROG).png|cp $(ICONS)$(PROG)-large.png $(ICONDIR)64x64/apps/$(PROG)1.png|' \
  ./makefile
sed -i 's|install -o root -g games -m 755 $(PROG) $(BINDIR)$(PROG)|install -o root -g games -m 755 $(PROG) $(BINDIR)$(PROG)1|' \
  ./makefile

make $numjobs
	
make install DESTDIR=$dest

# ----- treat icon-files
rm -rf $dest/usr/share/icons/hicolor/*
mkdir -p $dest/usr/share/icons/hicolor/16x16/apps
mkdir -p $dest/usr/share/icons/hicolor/22x22/apps
mkdir -p $dest/usr/share/icons/hicolor/24x24/apps
mkdir -p $dest/usr/share/icons/hicolor/32x32/apps
mkdir -p $dest/usr/share/icons/hicolor/36x36/apps
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
cd $builddir
tar -jxvf icons.tar.bz2 --directory=$builddir
mv icon-blobwars1-16.png $dest/usr/share/icons/hicolor/16x16/apps/blobwars1.png
mv icon-blobwars1-22.png $dest/usr/share/icons/hicolor/22x22/apps/blobwars1.png
mv icon-blobwars1-24.png $dest/usr/share/icons/hicolor/24x24/apps/blobwars1.png
mv icon-blobwars1-32.png $dest/usr/share/icons/hicolor/32x32/apps/blobwars1.png
mv icon-blobwars1-36.png $dest/usr/share/icons/hicolor/36x36/apps/blobwars1.png
mv icon-blobwars1-48.png $dest/usr/share/icons/hicolor/48x48/apps/blobwars1.png
mv icon-blobwars1-64.png $dest/usr/share/icons/hicolor/64x64/apps/blobwars1.png
cp icons.tar.bz2 $destsrc

# ----- make .desktop-files
rm -f $dest/usr/share/applications/*
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Blobwars 1: Metal Blob Solid
Exec=blobwars1
Icon=blobwars1
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
# ----- packaging
chown -R root.root $dest
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $package.dep
coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,perl,sdl,sysfsutils,xorg,xterm,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
